durationtools.durations_to_nonreduced_fractions_with_common_denominator
=======================================================================

.. autofunction:: abjad.tools.durationtools.durations_to_nonreduced_fractions_with_common_denominator.durations_to_nonreduced_fractions_with_common_denominator
   :noindex:
